@@ -55,6 +55,12 @@ class Loader(importlib.abc.Loader):
                 ):
                     annotation = statement.annotation.value
                     docstring_content = inspect.cleandoc(annotation)
+                elif (
+                    isinstance(statement, ast.AnnAssign)
+                    and isinstance(statement.annotation, ast.Name)
+                    and self.type_hint
+                ):
+                    return_type = statement.annotation.id
                 elif (
                     isinstance(statement, ast.AnnAssign)
                     and isinstance(statement.annotation, ast.Subscript)
@@ -73,7 +79,9 @@ class Loader(importlib.abc.Loader):
                     inspect.Parameter(
                         # FIXME: When a constant is passed to a function, this name generation process fails
                         #          Workaround is to use keyword args
-                        frame_info.get_source(arg) if frame_info.get_source(arg).isidentifier() else "p%d" % i,
+                        frame_info.get_source(arg)
+                        if frame_info.get_source(arg).isidentifier()
+                        else "p%d" % i,
                         annotation=type(value)
                         if self.type_hint
                         else inspect.Parameter.empty,
